#!/usr/bin/env node
// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-cli-policies
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

/********************************************************* {COPYRIGHT-TOP} ***
 * IBM Confidential
 * OCO Source Materials
 * 5725-C11, 5725-C12, 7198-8FX, 5725-F70, 5725-F71, 5725-F72, 5725-L30
 *
 * (C) Copyright IBM Corporation 2015  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has been
 * deposited with the U.S. Copyright Office.
 ********************************************************* {COPYRIGHT-END} **/
var g = require('strong-globalize')();

module.exports = {
  name: 'spaces',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: getTopics,
};

function getTopics() {
  return [ {
    name: 'spaces',
    commands: [
      {
        command: 'list',
        aliases: [ 'spaces' ],
        loginRequired: true,
        helpInfo: g.f('apic_spaces_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').spacesList(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'get <name>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_get_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').spacesGet(name, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'create <displayName>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_create_help.txt'),
        action: function(displayName, opts) {
          return require('./plugin-impl').spacesCreate(displayName, opts);
        },
        options: [
          { name: 'name' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'delete <name>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_delete_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').spacesDelete(name, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
      {
        command: 'set <name>',
        loginRequired: true,
        helpInfo: g.f('apic_spaces_set_help.txt'),
        action: function(name, opts) {
          return require('./plugin-impl').spacesSet(name, opts);
        },
        options: [
          { name: 'name' },
          { name: 'display-name' },
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.hostname', required: true },
        ],
      },
    ],
  },
  ];
};
